==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateToClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClass;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClassSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class GenerateToClassSetImpl extends InstanceSet<GenerateToClassSet,GenerateToClass> implements GenerateToClassSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateToClass generatetoclass : this ) generatetoclass.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateToClass generatetoclass : this ) generatesmeventstatementset.add( generatetoclass.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateToClass nullElement() {
        return GenerateToClassImpl.EMPTY_GENERATETOCLASS;
    }

    @Override
    public GenerateToClassSet emptySet() {
      return new GenerateToClassSetImpl();
    }

    @Override
    public GenerateToClassSet value() {
        return this;
    }

    @Override
    public List<GenerateToClass> elements() {
        return Arrays.asList(toArray(new GenerateToClass[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateToClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClass;
import io.ciera.tool.sql.ooaofooa.event.GenerateToClassSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GenerateToClassSetImpl extends InstanceSet<GenerateToClassSet,GenerateToClass> implements GenerateToClassSet {

    public GenerateToClassSetImpl() {
    }

    public GenerateToClassSetImpl(Comparator<? super GenerateToClass> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateToClass generatetoclass : this ) generatetoclass.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateToClass generatetoclass : this ) generatesmeventstatementset.add( generatetoclass.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateToClass nullElement() {
        return GenerateToClassImpl.EMPTY_GENERATETOCLASS;
    }

    @Override
    public GenerateToClassSet emptySet() {
      return new GenerateToClassSetImpl();
    }

    @Override
    public GenerateToClassSet emptySet(Comparator<? super GenerateToClass> comp) {
      return new GenerateToClassSetImpl(comp);
    }

    @Override
    public GenerateToClassSet value() {
        return this;
    }

    @Override
    public List<GenerateToClass> elements() {
        return Arrays.asList(toArray(new GenerateToClass[0]));
    }

}
